@@ -1,4 +1,4 @@
-(* netcgi_mod.mli
+(* netcgi_apache.mli
 
    Copyright (C) 2005-2006
 
@@ -14,7 +14,7 @@
    LICENSE for more details.
 *)
 
-(** Apache "mod" connector.
+(** Netcgi Apache "mod" connector.
  *
  * See the {!Netcgi_mod.setup} section at the end of this file to know
  * how to configure Apache.
@@ -65,12 +65,14 @@ sig
     type t (** Apache [server_rec] structure. *)
 
     external hostname : t -> string 	= "netcgi2_apache_server_hostname"
-      (** [server_rec] [hostname] field (as declared in Apache
-	  configuration file).
+      (** [server_hostname] field (as declared in Apache configuration file).
 	  @raise Not_found if NULL. *)
     external admin : t -> string	= "netcgi2_apache_server_admin"
-    external port : t -> int		= "netcgi2_apache_server_port"
+      (** [server_admin] field.
+	  @raise Not_found if NULL. *)
     external is_virtual : t -> bool	= "netcgi2_apache_server_is_virtual"
+      (** [is_virtual] field.
+	  @raise Not_found if NULL. *)
   end
 
   module Connection :
@@ -78,10 +80,11 @@ sig
     type t (** Apache [conn_rec] structure. *)
 
     external remote_ip : t -> string 	= "netcgi2_apache_connection_remote_ip"
-      (** [conn_rec] [remote_ip] field. Throws [Not_found] if NULL. *)
-    external auth_type : t -> string = "netcgi2_apache_connection_ap_auth_type"
+      (** [conn_rec] [remote_ip] field.
+          @raise Not_found if NULL. *)
     external remote_host : t -> string = "netcgi2_apache_connection_remote_host"
-    external user : t -> string		= "netcgi2_apache_connection_user"
+      (** [conn_rec] [remote_host] field.
+          @raise Not_found if NULL. *)
   end
 
   module Request :
@@ -94,13 +97,17 @@ sig
     external server : t -> Server.t 	= "netcgi2_apache_request_server"
       (** [request_rec] [server] field. *)
     external next : t -> t 		= "netcgi2_apache_request_next"
-      (** [request_rec] [next] field. Raises [Not_found] if NULL. *)
+      (** [request_rec] [next] field.
+          @raise Not_found if NULL. *)
     external prev : t -> t 		= "netcgi2_apache_request_prev"
-      (** [request_rec] [prev] field. Raises [Not_found] if NULL. *)
+      (** [request_rec] [prev] field.
+          @raise Not_found if NULL. *)
     external main : t -> t 		= "netcgi2_apache_request_main"
-      (** [request_rec] [main] field. Raises [Not_found] if NULL. *)
+      (** [request_rec] [main] field.
+          @raise Not_found if NULL. *)
     external the_request : t -> string 	= "netcgi2_apache_request_the_request"
-      (** [request_rec] [the_request] field. Throws [Not_found] if NULL. *)
+      (** [request_rec] [the_request] field.
+          @raise Not_found if NULL. *)
     external assbackwards : t -> bool	= "netcgi2_apache_request_assbackwards"
       (** [request_rec] [assbackwards] field; [true] if HTTP/0.9,
 	  "simple" request. *)
@@ -154,33 +161,34 @@ sig
       (** [request_rec] [notes] field. *)
     external content_type : t -> string
       = "netcgi2_apache_request_content_type"
-      (** [request_rec] [content_type] field. Throws [Not_found] if NULL. *)
+      (** [request_rec] [content_type] field.
+          @raise Not_found if NULL. *)
     external set_content_type : t -> string -> unit
       = "netcgi2_apache_request_set_content_type"
       (** Set [request_rec] [content_type] field. *)
 
-    external user : t -> string = "netcgi2_apache_request_user"
-      (** The authenticated user.  In Apache 1.3 this field is actually
-          in the [conn_rec] structure, and was moved here in Apache
-          2.0.  We transparently hide this detail for you.
-          @raise Not_found if NULL. *)
-
     external uri : t -> string = "netcgi2_apache_request_uri"
-      (** [request_rec] [uri] field. Throws [Not_found] if NULL. *)
+      (** [request_rec] [uri] field.
+          @raise Not_found if NULL. *)
+    external port : t -> int		= "netcgi2_apache_request_port"
+      (** Server port. *)
     external set_uri : t -> string -> unit = "netcgi2_apache_request_set_uri"
       (** Set [request_rec] [uri] field. *)
     external filename : t -> string = "netcgi2_apache_request_filename"
-      (** [request_rec] [filename] field. Throws [Not_found] if NULL. *)
+      (** [request_rec] [filename] field.
+          @raise Not_found if NULL. *)
     external set_filename : t -> string -> unit
       = "netcgi2_apache_request_set_filename"
       (** Set [request_rec] [filename] field. *)
     external path_info : t -> string = "netcgi2_apache_request_path_info"
-      (** [request_rec] [path_info] field. Throws [Not_found] if NULL. *)
+      (** [request_rec] [path_info] field.
+          @raise Not_found if NULL. *)
     external set_path_info : t -> string -> unit
       = "netcgi2_apache_request_set_path_info"
       (** Set [request_rec] [path_info] field. *)
     external args : t -> string = "netcgi2_apache_request_args"
-      (** [request_rec] [args] field. Throws [Not_found] if NULL. *)
+      (** [request_rec] [args] field.
+          @raise Not_found if NULL. *)
     external set_args : t -> string -> unit
       = "netcgi2_apache_request_set_args"
       (** Set [request_rec] [args] field. *)
@@ -216,6 +224,10 @@ sig
       (** Discard client request body.
           @raise Netcgi_common.HTTP in case of problems. *)
 
+    external user : t -> string = "netcgi2_apache_request_user"
+      (** The authenticated user.
+          @raise Not_found if NULL. *)
+    external auth_type : t -> string = "netcgi2_apache_auth_type"
     external note_auth_failure : t -> unit
       = "netcgi2_apache_request_note_auth_failure"
       (** Set headers to tell browser that authentication failed. *)
@@ -242,10 +254,9 @@ sig
 	  and Content-Type with [set_status] and [set_content_type]
 	  respectively. *)
 
-    external rflush : t -> int
-      = "netcgi2_apache_request_rflush"
+    val rflush : t -> unit
       (** Flush any buffered data waiting to be written to the client.
-          Returns [0] on success and [-1] for EOF.  *)
+          @raise End_of_file if it is not possible. *)
 
     external print_char : t -> char -> unit =
       "netcgi2_apache_request_print_char"
@@ -275,6 +286,7 @@ end
 
 (* ---------------------------------------------------------------------- *)
 
+(** Registering Apache handlers. *)
 module Handler :
 sig
   type result =
@@ -284,21 +296,21 @@ sig
                      declines to handle the phase; the server tries to
                      find another. *)
       | DONE	 (** The request is completely satisfied. *)
+      | HTTP of int (** The request returns the HTTP status code given
+                        as argument. *)
 
   type t = Apache.Request.t -> result
-  (** The type of handler functions.  May raise
-      [Netcgi_common.HTTP(st, msg)] to indicate that a response with
-      status [st] must be sent.  The exception [Exit] is considered as
-      a normal way of terminating early.  All other exceptions are
-      logged and result in an Internal_server_error response by
-      Apache. *)
+    (** The type of handler functions.  The exception [Exit] is
+        considered as a normal way of terminating early.  All other
+        exceptions are logged and result in an Internal_server_error
+        response by Apache. *)
 
   val register : t -> string -> unit
     (** Modules may call [register fn name] to register one or more
         handler functions.  The handler functions are then referred to
-        in the [Caml*Handler] configuration commands as
+        in the [Netcgi*Handler] configuration commands as
         [Module_name.name] where [Module_name] is derived from the
-        filename (given to the [CamlLoad] directive) and [name] is the
+        filename (given to the [NetcgiLoad] directive) and [name] is the
         string passed here.  *)
 end
 
@@ -342,24 +354,42 @@ val run :
 
 (** {2:setup Setup}
 
-    In order to use the above function, you need to have mod_caml
-    installed (in fact, only partly, as we only use [Apache] and
-    [Mod_caml] -- and thus also [Mod_caml_config]).
-
+    {3 Apache 1.3}
 
     You need to put in an Apache configuration file (we recommend
-    /etc/apache/conf.d/netcgi_apache) the following line:
+    /etc/apache/conf.d/netcgi_apache.conf) the following lines:
     {v
-    LoadModule netcgi_module /usr/lib/apache/1.x/netcgi_apache.so
+    LoadModule netcgi_module /usr/lib/apache/1.3/mod_netcgi_apache.so
+    NetcgiLoad pcre/pcre.cma
+    NetcgiLoad netsys/netsys.cma
+    NetcgiLoad netstring/netstring.cma
+    NetcgiLoad str.cma
+    NetcgiLoad netcgi2/netcgi.cma
+    NetcgiLoad netcgi2-apache/netcgi_apache.cma
     v}
-    for Apache 1.x and
+
+    {3 Apache 2.2 or later}
+
+    You need to put in an Apache configuration file (we recommend
+    /etc/apache2/mods-available/netcgi_apache.load) the following line:
     {v
-    LoadModule netcgi_module /usr/lib/apache/2.x/netcgi_apache.so
+    LoadModule netcgi_module /usr/lib/apache2/modules/mod_netcgi_apache.so
+    NetcgiLoad pcre/pcre.cma
+    NetcgiLoad netsys/netsys.cma
+    NetcgiLoad netstring/netstring.cma
+    NetcgiLoad str.cma
+    NetcgiLoad netcgi2/netcgi.cma
+    NetcgiLoad netcgi2-apache/netcgi_apache.cma
     v}
-    for Apache 2.x.
+    and make a symbolic link from /etc/apache2/mods-enabled/ to it to
+    actually enable it.  Subsequent configuration is recommended to be
+    in /etc/apache2/mods-available/netcgi_apache.conf (also to be
+    linked to /etc/apache2/mods-enabled/).
+
+    {3 Loading libraries}
 
     If your scripts depend on other libraries, you need to load them
-    using NetcgiLoad.  More specifically, if your library is x.cma and
+    using [NetcgiLoad].  More specifically, if your library is x.cma and
     is in the subdirectory y of standard OCaml directory (given by
     `ocamlc -where`), use
     {v
@@ -368,6 +398,9 @@ val run :
     If x.cma is not in a subdirectory of `ocamlc -where`, you need to
     specify the full path.
 
+
+    {3 Installing scripts}
+
     You need also to tell Apache how to detect whether a script is to
     be handled by netcgi_apache, either by putting them in a special
     directory (here /caml-bin/):
@@ -380,10 +413,19 @@ val run :
       Allow from all
     </Location>
     v}
-    or by distinguishing them by their extension (here [.cmo]):
+    or by distinguishing them by their extension (here [.cma]):
     {v
     NetcgiHandler Netcgi_apache.bytecode
-    AddHandler ocaml-bytecode .cmo
+    AddHandler ocaml-bytecode .cma
     v}
+
+    {3 Compiling scripts}
+
+    If your script reside in the file [x.ml], compile it to [x.cmo] or
+    [x.cma].  If your script depends on other libraries, you may
+    either load them with [NetcgiLoad] (see above) or include them in
+    [x.cma].  You need not include the [netcgi_apache.cma],
+    [netcgi.cma], [netstring.cma], [netsys.cma], or [pcre.cma] modules
+    as these are already loaded into Apache (see above).
 *)
 
