@@ -1,4 +1,4 @@
-(* $Id: telnet_client.ml 1057 2006-12-17 19:45:43Z gerd $
+(* $Id: telnet_client.ml 1121 2007-05-06 18:20:37Z gerd $
  * ----------------------------------------------------------------------
  *
  *)
@@ -533,8 +533,9 @@ class telnet_session =
 
 	    let addr = self # inet_addr hostname in
 
+	    let dom = Netsys.domain_of_inet_addr addr in
 	    let s = syscall 
-		      (fun () -> Unix.socket Unix.PF_INET Unix.SOCK_STREAM 0) in
+		      (fun () -> Unix.socket dom Unix.SOCK_STREAM 0) in
 	    (* Connect in non-blocking mode: *)
 	    syscall (fun () -> Unix.set_nonblock s);
 	    (* Urgent data is received inline: *)
