@@ -1,4 +1,4 @@
-(* $Id: mimestring.ml,v 2.16 2004/11/24 18:01:14 gremlin43820 Exp $
+(* $Id: mimestring.ml 1062 2006-12-17 20:17:36Z gerd $
  * ----------------------------------------------------------------------
  *
  *)
@@ -348,7 +348,7 @@ let create_mime_scanner ~specials ~scan_options =
 let encoded_word_re =
   S.regexp "=\\?([^?]+)\\?([^?]+)\\?([^?]+)\\?=";;
 
-let scan_next_token ((spec,target) as scn) =
+let scan_next_token (spec,target) =
   let mk_pair t len =
     { token = t;
       token_pos = target.scanner_pos;
@@ -477,7 +477,7 @@ let scan_next_token ((spec,target) as scn) =
     if i < l then
       let c = s.[i] in
       match c with
-	  ('\000'..'\031'|'\127'..'\255'|'"'|'('|'['|' '|'\t'|'\r'|'\n') ->
+	  ('\000'..'\031'|'\127'..'\255'|'"'|'('|'['|' ') ->
 	    return_atom()
 	| _ ->
 	    if spec.is_special.( Char.code c ) then
@@ -632,7 +632,7 @@ let scan_token ((spec,target) as scn) =
 	 * twice. (The sole purpose of the queue.)
 	 *)
 	match target.last_token with
-	    EncodedWord(_,_,_) as ew ->
+	    EncodedWord(_,_,_) ->
 	      let ws_list, tok = collect_whitespace() in
 	      (* If tok is an EncodedWord, too, the tokens in ws_list must
 	       * be flagged as separating two adjacent encoded words. 
@@ -1744,106 +1744,3 @@ let create_boundary ?(random = []) ?(nr = 0) () =
     hex
     nr
 ;;
-
-
-(* ======================================================================
- * History:
- *
- * $Log: mimestring.ml,v $
- * Revision 2.16  2004/11/24 18:01:14  gremlin43820
- * commiting fastcgi compatibility patch from Kristof Pap which allows us to talk to a wider variety of fastcgi enabled web servers, and more closely follows the standard.
- *
- * Revision 2.15  2004/07/06 15:20:53  stolpmann
- * 	Bugfixes: write_value now correctly folds long encoded words.
- *
- * Revision 2.14  2004/07/04 18:51:54  stolpmann
- * 	Added: split_mime_type, split_uri
- *
- * Revision 2.13  2004/05/30 21:22:00  stolpmann
- * 	Fixed bug when parsing backslashes within double quotes
- *
- * Revision 2.12  2002/02/02 16:10:47  stolpmann
- * 	Bugfix: read_header recognizes empty headers.
- *
- * Revision 2.11  2002/02/01 23:26:22  stolpmann
- * 	Fixed some problems with mail from the real world
- *
- * Revision 2.10  2002/01/23 22:15:18  stolpmann
- * 	New function: [create_boundary]
- *
- * Revision 2.9  2002/01/21 00:45:39  stolpmann
- * 	[scan_header]: New option ~strip, so you can turn off unfolding
- * but leave whitespace stripping on.
- * 	New: [write_header], [mk_param], [write_value], [param_tokens]
- *
- * Revision 2.8  2002/01/12 18:07:34  stolpmann
- * 	Added support for RFC 2231: get_language,
- * scan_value_with_parameters_ep, and scan_mime_type_ep. There is one
- * incompatible change regarding EncodedWord. The definition has been
- * changed from EncodedWord(charset,encoding,value) to
- * EncodedWord((charset,language),encoding,value), i.e. the first
- * component is now the pair of the character set and the language.
- * EncodedWord is still a triple, so code ignoring the first component
- * will continue working (e.g. match...with EncodedWord(_,_,_) -> ...)
- *
- * Revision 2.7  2002/01/06 02:22:09  stolpmann
- * 	New parser for headers: [read_header].
- * 	New parser for multipart messages: [read_multipart_body]. The
- * old functions [scan_multipart_body], [scan_multipart_body_and_decode],
- * and [scan_multipart_body_from_netstream] are derived from this new
- * parser.
- *
- * Revision 2.6  2002/01/05 19:40:31  stolpmann
- * 	Follow-up change: method [delete] of netstreams renamed into
- * [skip].
- *
- * Revision 2.5  2002/01/04 22:01:06  stolpmann
- * 	No longer using deprecated Base64 functions.
- *
- * Revision 2.4  2001/12/28 21:14:00  stolpmann
- * 	[scan_multipart_body_from_netstream] uses now the new
- * object-oriented interface of Netstream.
- * 	Renamed Str into S to make clear that this module is not
- * the standard Str module.
- *
- * Revision 2.3  2001/10/17 04:32:52  pdoane
- * Updated for 3.03
- *
- * Revision 2.2  2001/09/23 20:39:42  pdoane
- * Migration to PCRE
- *
- * Revision 2.1  2001/09/14 14:22:34  stolpmann
- * 	Initial revision (sourceforge)
- *
- *
- * ======================================================================
- * Revision 1.9  2001/07/01 10:25:10  gerd
- * 	Fixed: string_partial_match does not what I expected.
- *
- * Revision 1.8  2000/08/13 00:04:36  gerd
- * 	Encoded_word -> EncodedWord
- * 	Bugfixes.
- *
- * Revision 1.7  2000/08/07 00:25:14  gerd
- * 	Implemented the new functions for structured field lexing.
- *
- * Revision 1.6  2000/06/25 22:34:43  gerd
- * 	Added labels to arguments.
- *
- * Revision 1.5  2000/06/25 21:15:48  gerd
- * 	Checked thread-safety.
- *
- * Revision 1.4  2000/05/16 22:30:14  gerd
- * 	Added support for some types of malformed MIME messages.
- *
- * Revision 1.3  2000/04/15 13:09:01  gerd
- * 	Implemented uploads to temporary files.
- *
- * Revision 1.2  2000/03/02 01:15:30  gerd
- * 	Updated.
- *
- * Revision 1.1  2000/02/25 15:21:12  gerd
- * 	Initial revision.
- *
- *
- *)
