@@ -1,4 +1,4 @@
-(* $Id: netchannels.ml,v 1.19 2005/04/14 20:13:19 stolpmann Exp $
+(* $Id: netchannels.ml 1012 2006-10-02 13:12:56Z gerd $
  * ----------------------------------------------------------------------
  *
  *)
@@ -1228,7 +1228,7 @@ let lift_out ?(buffered=true) ?buffer_size (x : lift_out_arg) =
 
 (************************* raw channels *******************************)
 
-class input_descr_prelim ?(start_pos_in = 0) fd =
+class input_descr_prelim ?(blocking=true) ?(start_pos_in = 0) fd =
 object (self)
   val fd_in = fd
   val mutable pos_in = start_pos_in
@@ -1249,7 +1249,12 @@ object (self)
 	  self # input buf pos len
       | Unix.Unix_error(Unix.EAGAIN,_,_)
       | Unix.Unix_error(Unix.EWOULDBLOCK,_,_) ->
-	  0
+	  if blocking then (
+	    let _  = Netsys.restarting_select [fd] [] [] (-1.0) in
+	    self # input buf pos len
+	  )
+	  else 0
+	  
   
   method close_in () =
     if closed_in then self # complain_closed();
@@ -1262,12 +1267,12 @@ end
 ;;
 
 
-class input_descr ?start_pos_in fd : raw_in_channel = 
-  input_descr_prelim ?start_pos_in fd
+class input_descr ?blocking ?start_pos_in fd : raw_in_channel = 
+  input_descr_prelim ?blocking ?start_pos_in fd
 ;;
 
 
-class output_descr_prelim ?(start_pos_out = 0) fd =
+class output_descr_prelim ?(blocking=true) ?(start_pos_out = 0) fd =
 object (self)
   val fd_out = fd
   val mutable pos_out = start_pos_out
@@ -1287,7 +1292,12 @@ object (self)
 	  self # output buf pos len
       | Unix.Unix_error(Unix.EAGAIN,_,_)
       | Unix.Unix_error(Unix.EWOULDBLOCK,_,_) ->
-	  0
+	  if blocking then (
+	    let _  = Netsys.restarting_select [] [fd] [] (-1.0) in
+	    self # output buf pos len
+	  )
+	  else
+	    0
   
   method close_out () =
     if closed_out then self # complain_closed();
@@ -1303,16 +1313,16 @@ end
 ;;
 
 
-class output_descr ?start_pos_out fd : raw_out_channel =
-  output_descr_prelim ?start_pos_out fd 
+class output_descr ?blocking ?start_pos_out fd : raw_out_channel =
+  output_descr_prelim ?blocking ?start_pos_out fd 
 ;;
 
 
-class socket_descr ?(start_pos_in = 0) ?(start_pos_out = 0) fd 
+class socket_descr ?blocking ?(start_pos_in = 0) ?(start_pos_out = 0) fd 
       : raw_io_channel =
 object (self)
-  inherit input_descr_prelim ~start_pos_in fd
-  inherit output_descr_prelim ~start_pos_out fd 
+  inherit input_descr_prelim ?blocking ~start_pos_in fd
+  inherit output_descr_prelim ?blocking ~start_pos_out fd 
   
   method close_in () =
     if closed_in then self # complain_closed();
@@ -1569,6 +1579,12 @@ object(self)
   val input_super = new input_netbuffer _outgoing
 
   val mutable incoming_eof = false
+  val mutable pos_in = 0
+    (* We must count positions ourselves. Can't use input_super#pos_in
+     * because conv may manipulate the buffer.
+     *)
+
+  val mutable output_closed = false
 
   (* Input methods: *)
 
@@ -1577,32 +1593,49 @@ object(self)
     if incoming_eof then input_super # shutdown()
 
 
-  method input str pos =
-    call_input self#refill (input_super#input str pos)
+  method input str pos len =
+    let n = call_input self#refill (input_super#input str pos) len in
+    pos_in <- pos_in + n;
+    n
 
-  method input_line =
-    call_input self#refill (input_super#input_line)
+  method input_line() =
+    let p = input_super # pos_in in
+    let line = call_input self#refill (input_super#input_line) () in
+    let p' = input_super # pos_in in
+    pos_in <- pos_in + (p' - p);
+    line
 
-  method really_input str pos =
-    call_input self#refill (input_super#really_input str pos)
+  method really_input str pos len =
+    call_input self#refill (input_super#really_input str pos) len;
+    pos_in <- pos_in + len
 
-  method input_char =
-    call_input self#refill (input_super#input_char)
+  method input_char() =
+    let c = call_input self#refill (input_super#input_char) () in
+    pos_in <- pos_in + 1;
+    c
 
-  method input_byte =
-    call_input self#refill (input_super#input_byte)
+  method input_byte() =
+    let b = call_input self#refill (input_super#input_byte) () in
+    pos_in <- pos_in + 1;
+    b
 
   method close_in() =
     (* [close_in] implies [close_out]: *)
-    output_super # close_out();
+    if not output_closed then (
+      output_super # close_out();
+      output_closed <- true;
+    );
     input_super # close_in()
 
-  method pos_in = input_super#pos_in
+  method pos_in = pos_in
 
   (* [close_out] also shuts down the input side of the pipe. *)
 
   method close_out () =
-    output_super # close_out();
+    if not output_closed then (
+      output_super # close_out();
+      output_closed <- true;
+    );
     incoming_eof <- true
 
 end
@@ -1730,92 +1763,3 @@ object(self)
   method pos_in = p#pos_in
 
 end
-
-(* ======================================================================
- * History:
- * 
- * $Log: netchannels.ml,v $
- * Revision 1.19  2005/04/14 20:13:19  stolpmann
- * Using Unix.single_write instead of Unix.write.
- *
- * Revision 1.18  2004/07/11 15:40:29  stolpmann
- * 	Added: enhanced_input
- *
- * Revision 1.17  2004/07/10 23:42:36  stolpmann
- * 	New: delegation classes
- * 	New: Arg eol of lift_in
- * 	ocamldoc
- *
- * Revision 1.16  2004/05/30 21:27:14  stolpmann
- * 	Supporting the standard for class-based I/O. This also means
- * the semantics of [input] and [output] methods have changed (return
- * value 0, End_of_file).
- * 	Removed _rep_in, _rep_out.
- * 	Removed Netstream.Deprecated.
- *
- * Revision 1.15  2002/11/01 17:11:07  stolpmann
- * 	Changed EAGAIN -> EINTR
- *
- * Revision 1.14  2002/10/26 20:47:37  stolpmann
- * 	Change: [flush] is now part of [raw_out_channel].
- * 	New: [augment_raw_in_channel], [augment_raw_out-channel],
- * [buffered_raw_in_channel], [buffered_raw_out_channel].
- * 	Fixed: [input_descr], [output_descr], [socket_descr] no longer
- * seek to find out the position.
- *
- * Revision 1.13  2002/10/24 23:33:23  stolpmann
- * 	New class output_null that simply discards any output
- *
- * Revision 1.12  2002/02/02 23:53:06  stolpmann
- * 	New: input_command, output_command
- *
- * Revision 1.11  2002/02/02 19:09:43  stolpmann
- * 	Important optimization: output_filter#output_channel processes
- * the channel block by block, so large buffers are avoided.
- *
- * Revision 1.10  2002/01/12 18:35:17  stolpmann
- * 	Added ?onclose for some output classes.
- *
- * Revision 1.9  2002/01/06 02:20:13  stolpmann
- * 	New optional arguments ?pos and ?len for class [input_string].
- *
- * Revision 1.8  2002/01/05 22:43:54  stolpmann
- * 	New: classes [input_filter], [output_filter]
- *
- * Revision 1.7  2002/01/02 22:55:09  stolpmann
- * 	Added: [input_netbuffer], [output_netbuffer], [pipe]. New
- * exception [Buffer_underrun].
- *
- * Revision 1.6  2001/12/22 09:17:15  pdoane
- * 	Added raw_*_channel types
- * 	Changed output to really_output for out_obj_channel
- * 	Added file_descr/socket_descr implementations
- * 	Renamed buffered_output_channel and tempfile_output_channel
- *
- * Revision 1.5  2001/11/11 21:14:23  pdoane
- * 	Fixed bugs in the verification of arguments to the input and
- * 	really_input methods of input_string.
- *
- * Revision 1.4  2001/10/06 23:56:16  stolpmann
- * 	[tempfile_output_channel]: works now for multiple commit/rollback
- * cycles. The problem was that the channel buffer of transch_in lost
- * the synchronization with the actual tempfile.
- *
- * Revision 1.3  2001/09/30 00:01:46  stolpmann
- *         New function: make_temporary_file.
- *         For the class tempfile_output_channel: the default tmp_directory
- * is now "." (it is difficult to have a reasonable automatic tmp_directory
- * for the scope of netchannels only)
- *         with_in/out_obj_channel: It is ok if the channel is already
- * closed.
- *
- * Revision 1.2  2001/09/28 21:20:05  stolpmann
- * 	New functions:
- * 	- string_of_in_obj_channel
- * 	- with_in_obj_channel, with_out_obj_channel
- *
- * Revision 1.1  2001/09/24 21:23:17  stolpmann
- * 	Initial revision.
- *
- * 
- *)
