@@ -1,4 +1,4 @@
-(* $Id: netconversion.ml,v 2.20 2004/07/11 15:41:18 stolpmann Exp $
+(* $Id: netconversion.ml 1084 2007-02-20 12:36:17Z gerd $
  * ----------------------------------------------------------------------
  *)
 
@@ -52,6 +52,7 @@ type encoding =
   |  `Enc_jis0212_94x94  (* JIS-X-0212 in ISO-2022-style two byte encoding *)
 *)
   |  `Enc_eucjp      (* EUC-JP *)
+  |  `Enc_euckr      (* EUC-KR *)
 (* 
   |  `Enc_iso2022 of iso2022_state
   |  `Enc_iso2022jp of iso2022jp_state
@@ -136,6 +137,7 @@ type charset =
   |  `Set_jis0201    (* JIS-X-0201 *)
   |  `Set_jis0208    (* JIS-X-0208 *)
   |  `Set_jis0212    (* JIS-X-0212 *)
+  |  `Set_ks1001     (* KS-X-1001 *)
     (* Microsoft: *)
   |  `Set_windows1250  (* WINDOWS-1250 *)
   |  `Set_windows1251  (* WINDOWS-1251 *)
@@ -195,7 +197,7 @@ let ascii_compat_encodings =
     `Enc_cp437; `Enc_cp737; `Enc_cp775; `Enc_cp850; `Enc_cp852; `Enc_cp855;
     `Enc_cp856; `Enc_cp857; `Enc_cp860; `Enc_cp861; `Enc_cp862; `Enc_cp863;
     `Enc_cp864; `Enc_cp865; `Enc_cp866; `Enc_cp869; `Enc_cp874; `Enc_cp1006;
-    `Enc_eucjp;
+    `Enc_eucjp; `Enc_euckr;
     `Enc_macroman;
   ]
 ;;
@@ -216,6 +218,7 @@ let rec is_single_byte =
     | `Enc_utf16_le
     | `Enc_utf16_be -> false
     | `Enc_eucjp -> false
+    | `Enc_euckr -> false
     | `Enc_subset(e,_) -> is_single_byte e
     | _ -> true
 ;;
@@ -287,6 +290,7 @@ let names =
     `Enc_koi8r,        [ "KOI8-R"; "KOI8R"; "CP878" ];
     `Enc_jis0201,      [ "JIS_X0201"; "JIS0201"; "JISX0201"; "X0201" ];
     `Enc_eucjp,        [ "EUC-JP"; "EUCJP"; ];
+    `Enc_euckr,        [ "EUC-KR"; "EUCKR"; ];
     `Enc_windows1250,  [ "WINDOWS-1250"; "WINDOWS1250" ];
     `Enc_windows1251,  [ "WINDOWS-1251"; "WINDOWS1251" ];
     `Enc_windows1252,  [ "WINDOWS-1252"; "WINDOWS1252" ];
@@ -386,6 +390,7 @@ let internal_name (cs : charset) =
     | `Set_jis0201 -> "jis0201"
     | `Set_jis0208 -> "jis0208"
     | `Set_jis0212 -> "jis0212"
+    | `Set_ks1001 -> "ks1001"
     | `Set_windows1250 -> "windows1250"
     | `Set_windows1251 -> "windows1251"
     | `Set_windows1252 -> "windows1252"
@@ -453,6 +458,7 @@ let rec required_charsets (e : encoding) =
     | `Enc_koi8r -> [ `Set_koi8r ]
     | `Enc_jis0201 -> [ `Set_jis0201 ]
     | `Enc_eucjp -> [ `Set_jis0201; `Set_jis0208; `Set_jis0212 ]
+    | `Enc_euckr -> [ `Set_ks1001 ]
     | `Enc_windows1250 -> [ `Set_windows1250 ]
     | `Enc_windows1251 -> [ `Set_windows1251 ]
     | `Enc_windows1252 -> [ `Set_windows1252 ]
@@ -1106,6 +1112,14 @@ let read_eucjp () =
 ;;
 
 
+let read_euckr () =
+  let ks1001 = Netmappings.get_to_unicode "ks1001" in
+  let map x1 x2 =
+    ks1001.( (x1-160) * 96 + x2 - 160 ) in
+  read_euc 2 0 0 map map map `Enc_euckr
+;;
+
+
 let read_subset inner_read def slice_char slice_blen s_in p_in l_in =
   assert(Array.length slice_char = Array.length slice_blen);
   assert(p_in >= 0 && p_in + l_in <= String.length s_in && l_in >= 0);
@@ -1652,6 +1666,43 @@ let write_eucjp () =
 ;;
 
 
+let write_euckr () =
+  let ks1001 = Netmappings.get_from_unicode "ks1001" in
+
+  let ks1001_mask = Array.length ks1001 - 1 in
+
+  let map p =
+    let map_tbl kstbl kstbl_mask =
+      match kstbl.(p land kstbl_mask) with
+	  Netmappings.U_nil -> -1
+	| Netmappings.U_single (p0,q0) ->
+	    if p0 = p then q0 else -1
+	| Netmappings.U_double (p0,q0,p1,q1) ->
+	    if p0 = p then q0 else
+	      if p1 = p then q1 else -1
+	| Netmappings.U_array pq ->
+	    let r = ref (-1) in
+	    let h = ref 0 in
+	    while !r < 0 && !h < Array.length pq do
+	      if pq.( !h ) = p then
+		r := pq.( !h+1 )
+	      else
+		h := !h + 2
+	    done;
+	    !r
+    in
+    let cp_1001 = map_tbl ks1001 ks1001_mask in
+    if cp_1001 >= 0 then
+      let row = cp_1001 / 96 in
+      let col = cp_1001 - row * 96 in
+      (1, row + 160, col + 160)
+    else
+      (4,256,256)
+  in
+  write_euc map `Enc_euckr
+;;
+
+
 let special_cpoint = 0x110000;;
 
 
@@ -1851,6 +1902,7 @@ let rec get_reader1 (enc : encoding1) =
     | `Enc_utf16_le -> read_utf16_lebe 0 1 0 `Enc_utf16_le
     | `Enc_utf16_be -> read_utf16_lebe 1 0 0 `Enc_utf16_be
     | `Enc_eucjp    -> read_eucjp ()
+    | `Enc_euckr    -> read_euckr ()
     | `Enc_subset(e,def) ->
 	let reader' = get_reader1 (e :> encoding1) in
 	read_subset reader' def
@@ -1874,6 +1926,7 @@ let rec get_writer enc =
     | `Enc_utf16_le -> write_utf16_lebe 0 1
     | `Enc_utf16_be -> write_utf16_lebe 1 0
     | `Enc_eucjp    -> write_eucjp ()
+    | `Enc_euckr    -> write_euckr ()
     | `Enc_subset(e,def) ->
 	let writer' = get_writer e in
 	write_subset writer' def
@@ -1890,6 +1943,7 @@ let rec get_back_fn enc =
     | `Enc_utf16_le -> back_utf16_lebe 0 1
     | `Enc_utf16_be -> back_utf16_lebe 1 0
     | `Enc_eucjp    -> back_euc
+    | `Enc_euckr    -> back_euc
     | `Enc_subset(e,def) ->
 	get_back_fn e
     | _ -> 
@@ -2021,6 +2075,7 @@ let rec ustring_of_uchar enc =
     | `Enc_utf16 ->
 	invalid_arg "Netconversion.ustring_of_uchar: UTF-16 not possible"
     | `Enc_eucjp -> multi_byte (write_eucjp()) 3
+    | `Enc_euckr -> multi_byte (write_euckr()) 2
     | `Enc_subset(e,def) ->
 	(fun p -> if def p then ustring_of_uchar e p else raise (Cannot_represent p))
     | _ ->
@@ -3107,133 +3162,3 @@ let ustring_of_uarray ?(subst = fun code -> raise (Cannot_represent code))
 
   String.sub !out_buf 0 !k_out
 ;;
-
-
-(* ======================================================================
- * History:
- * 
- * $Log: netconversion.ml,v $
- * Revision 2.20  2004/07/11 15:41:18  stolpmann
- * 	Added: IBM-1047 charset
- *
- * Revision 2.19  2004/07/08 22:10:18  stolpmann
- * 	Adding accelerators for character set conversion.
- *
- * Revision 2.18  2004/07/07 22:41:53  stolpmann
- * 	Added Netulex, Netaux.ArrayAux.
- * 	Some improvements in Netconversion.
- *
- * Revision 2.17  2004/06/20 13:12:37  stolpmann
- * 	Added some encoding names (code pages)
- *
- * Revision 2.16  2004/06/09 22:51:56  stolpmann
- * 	Enhanced cursors: Support for UTF-16 with BOMs, support for
- * incomplete multi-byte characters,b litting functions.
- * 	Added ocamldoc to Netconversion.
- * 	Updated test_recode: New tests for cursors.
- *
- * Revision 2.15  2003/06/17 18:33:05  stolpmann
- * 	Fix: "recode" works now if the reader runs into an invalid
- * byte sequence that should be ignored. New exception Malformed_code_read
- * (raised by readers) signals this condition.
- *
- * Revision 2.14  2003/06/17 15:33:33  stolpmann
- * 	Fix: correcting slice_blen by the size of the byte order
- * mark (UTF-16)
- *
- * Revision 2.13  2003/06/17 15:10:29  stolpmann
- * 	Fix: In "recode", it was possible that the max_chars parameter
- * was ignored
- *
- * Revision 2.12  2003/06/04 19:21:51  stolpmann
- * 	compile fixes
- *
- * Revision 2.11  2003/06/03 18:58:23  stolpmann
- * 	Fine-tuning
- *
- * Revision 2.10  2003/04/21 22:01:35  stolpmann
- * 	Change: subst functions raise Cannot_represent by default (only
- * in new functions)
- * 	Obsolete: recode_string, recoding_pipe, makechar
- * 	New: same_encoding, byte_order_mark, uchar_string, from_unicode,
- * available_input_encodings, available_output_encodings, convert,
- * conversion_pipe
- * 	New: cursor implementation
- * 	New: unicode string functions
- *
- * Revision 2.9  2003/04/06 22:10:58  stolpmann
- * 	Reimplementation of the conversions, now using an intermediate
- * array "slice"
- *
- * Revision 2.8  2002/10/04 20:54:31  stolpmann
- * 	Also accepting "MACROMAN" for Macintosh Roman encoding.
- *
- * Revision 2.7  2002/08/22 21:49:59  stolpmann
- * 	Fix: ISO-8859-16 is ascii-compatible, too.
- *
- * Revision 2.6  2002/07/06 16:23:23  stolpmann
- * 	Fix: It is now checked and documented that the substitution
- * strings must not be too long. The limit is multibyte_limit, currently
- * 50 bytes.
- *
- * Revision 2.5  2002/07/03 01:15:57  stolpmann
- * 	New: `Enc_subset
- * 	New: is_single_byte
- * 	New: to_unicode
- *
- * Revision 2.4  2002/06/23 20:58:59  stolpmann
- * 	Added: Support for ISO-8858-16 character encoding
- *
- * Revision 2.3  2002/06/23 19:47:03  stolpmann
- * 	New class: recoding_pipe.
- * 	Fix: A possible problem in recode_string has been solved.
- * 	Improved representation of character mappings.
- *
- * Revision 2.2  2001/11/15 22:09:50  stolpmann
- * 	Fix: write_utf16_le/_be generate correct surrogate pairs.
- *
- * Revision 2.1  2001/09/14 14:22:34  stolpmann
- * 	Initial revision (sourceforge)
- *
- *
- * ======================================================================
- * Revision 1.2  2000/08/29 00:46:41  gerd
- * 	New type for the Unicode to 8 bit translation table.
- * 	The Netmappings tables are now Lazy.t.
- *
- * Revision 1.1  2000/08/13 00:02:57  gerd
- * 	Initial revision.
- *
- *
- * ======================================================================
- * OLD LOGS FROM THE PXP PACKAGE (FILE NAME pxp_encoding.ml):
- * 
- * Revision 1.5  2000/07/27 00:41:14  gerd
- * 	new 8 bit codes
- *
- * Revision 1.4  2000/07/04 22:11:41  gerd
- * 	Implemented the enhancements and extensions of
- * rev. 1.4 of pxp_encoding.mli.
- *
- * Revision 1.3  2000/05/29 23:48:38  gerd
- * 	Changed module names:
- * 		Markup_aux          into Pxp_aux
- * 		Markup_codewriter   into Pxp_codewriter
- * 		Markup_document     into Pxp_document
- * 		Markup_dtd          into Pxp_dtd
- * 		Markup_entity       into Pxp_entity
- * 		Markup_lexer_types  into Pxp_lexer_types
- * 		Markup_reader       into Pxp_reader
- * 		Markup_types        into Pxp_types
- * 		Markup_yacc         into Pxp_yacc
- * See directory "compatibility" for (almost) compatible wrappers emulating
- * Markup_document, Markup_dtd, Markup_reader, Markup_types, and Markup_yacc.
- *
- * Revision 1.2  2000/05/29 21:14:57  gerd
- * 	Changed the type 'encoding' into a polymorphic variant.
- *
- * Revision 1.1  2000/05/20 20:30:50  gerd
- * 	Initial revision.
- *
- * 
- *)
