@@ -1,4 +1,4 @@
-(* $Id: netconversion.mli,v 2.13 2004/07/11 15:41:18 stolpmann Exp $
+(* $Id: netconversion.mli 1084 2007-02-20 12:36:17Z gerd $
  * ----------------------------------------------------------------------
  *)
 
@@ -226,7 +226,7 @@
  * that can be supported; especially ISO646 character sets, and many EBCDIC 
  * code pages. Stateful encodings like generic ISO-2022 have been omitted
  * (stateless subsets of ISO-2022 like EUC can be supported, however;
- * currently we support EUC-JP).
+ * currently we support EUC-JP and EUC-KR).
  *
  * Because of the copyright statement from Unicode, I cannot put the
  * source tables that describe the mappings into the distribution. They
@@ -287,6 +287,7 @@ exception Cannot_represent of int
  * - [`Enc_jis0201]: JIS-X-0201 (Roman and Katakana)
  * - [`Enc_eucjp]: EUC-JP (code points from US-ASCII, JIS-X-0202, -0208, and
  *   -0212)
+ * - [`Enc_euckr]: EUC-KR (code points from US-ASCII, KS-X-1001)
  * - [`Enc_windows]{i n}: WINDOWS-{i n}
  * - [`Enc_cp]{i n}: IBM code page {i n}. Note that there are both ASCII-
  *   and EBCDIC-based code pages
@@ -328,6 +329,7 @@ type encoding =
       This encoding is too weird.
   |  `Enc_sjis
 *)
+  |  `Enc_euckr      (* EUC-KR (includes US-ASCII, KS-X-1001) *)
     (* Microsoft: *)
   |  `Enc_windows1250  (* WINDOWS-1250 *)
   |  `Enc_windows1251  (* WINDOWS-1251 *)
@@ -404,6 +406,7 @@ type charset =
   |  `Set_jis0201    (* JIS-X-0201 *)
   |  `Set_jis0208    (* JIS-X-0208 *)
   |  `Set_jis0212    (* JIS-X-0212 *)
+  |  `Set_ks1001     (* KS-X-1001 *)
     (* Microsoft: *)
   |  `Set_windows1250  (* WINDOWS-1250 *)
   |  `Set_windows1251  (* WINDOWS-1251 *)
@@ -1332,121 +1335,6 @@ val verify : encoding -> ?range_pos:int -> ?range_len:int -> string -> unit
    *   (default: byte length of the input string minus [range_pos])
    *)
 
-
-(**********************************************************************)
-(* Lexing buffers                                                     *)
-(**********************************************************************)
-
-(* --- PLANNED
-   Currently implemented in Pxp_reader, but better we do it here.
-
-type unicode_lexbuf =
-    private
-      { mutable ulb_encoding : encoding;
-                (* The character encoding of [ulb_rawbuf] *)
-	mutable ulb_rawbuf : string;
-                (* The encoded string to analyse *)
-	mutable ulb_rawbuf_len : int;
-                (* The filled part of [ulb_rawbuf] *)
-	mutable ulb_rawbuf_end : int;
-                (* The analysed part of [ulb_rawbuf]. We have always
-	         * [ulb_rawbuf_end <= ulb_rawbuf_len]. The analysed part
-	         * may be shorter than the filled part because there is
-	         * not enough space in [ulb_chars], or because the filled
-	         * part ends with an incomplete multi-byte character
-	         *)
-	mutable ulb_chars : int array;
-                (* The analysed part of [ulb_rawbuf] as array of Unicode
-	         * code points. Only the positions 0 to [ulb_chars_len-1]
-	         * of the array are filled.
-	         *)
-	mutable ulb_chars_pos : int array;
-                (* For every analysed character this array stores the
-   	         * byte position where the character begins in [ulb_rawbuf].
-	         * In addition, the array contains at [ulb_chars_len] the
-	         * value of [ulb_rawbuf_end].
-		 *
-	         * This array is one element longer than [ulb_chars].
-	         *)
-	mutable ulb_chars_len : int;
-                (* The filled part of [ulb_chars] *)
-	mutable ulb_eof : bool;
-                (* Whether EOF has been seen *)
-      }
-
-val create_unicode_lexbuf : 
-      ?raw_size:int -> ?char_size:int -> encoding -> unicode_lexbuf
-  (** Creates an empty [unicode_lexbuf] to analyse strings of the 
-   * passed [encoding].
-   *
-   * @param raw_size The initial size for [ulb_rawbuf]. Defaults to 512
-   * @param char_size The initial size for [ulb_chars]. Defaults to 256
-   *)
-
-val unicode_lexbuf_from_string :
-      encoding -> string -> unicode_lexbuf
-  (** Creates a [unicode_lexbuf] analysing the passed string encoded in
-   * the passed encoding. This function copies the input string.
-   *)
-
-val unicode_lexbuf_from_string_inplace :
-      encoding -> string -> unicode_lexbuf
-  (** Creates a [unicode_lexbuf] analysing the passed string encoded in
-   * the passed encoding. This function does not copy the input string,
-   * but uses it directly as [ulb_rawbuf].
-   *)
-
-val append_to_unicode_lexbuf :
-      src:(int array) -> ?pos:int -> ?len:int -> unicode_lexbuf -> unit
-  (** Appends a sub array of [src] to the [unicode_lexbuf].
-   * When the buffer is already at EOF, the function fails.
-   *
-   * @param pos Where the sub array begins, by default 0
-   * @param len The length of the sub array, by default [Array.length - pos]
-   *)
-
-val delete_from_unicode_lexbuf :
-      int -> unicode_lexbuf -> unit
-  (** Deletes the number of characters from [unicode_lexbuf].
-   *  These characters
-   *  are removed from the beginning of the buffer, i.e.
-   *  [ulb_chars.(n)] becomes the new first character of the
-   *  buffer. All three buffers [ulb_rawbuf], [ulb_chars], and
-   *  [ulb_chars_pos] are blitted as necessary.       
-   *
-   *  When the buffer is already at EOF, the function fails.
-   *)
-
-val refill_unicode_lexbuf :
-      refill:(string -> int -> int -> int) ->
-      unicode_lexbuf ->
-	unit
-  (** Tries to add characters to the [unicode_lexbuf] by calling the 
-   * [refill] function. When the buffer is already at EOF, the 
-   * exception [End_of_file] is raised, and the buffer is not modified.
-   * Otherwise, the [refill] function is called to
-   * add new characters. If necessary, [ulb_rawbuf], [ulb_chars], and
-   * [ulb_chars_pos] are enlarged such that it is ensured that either
-   * at least one new character is added, or that EOF is found.
-   * In the latter case, [ulb_eof] is set to [true] (and the next call
-   * of [refill_unicode_lexbuf] will raise [End_of_file]).
-   *
-   * @param refill This function is called with arguments [ulb_rawbuf],
-   *   [ulb_rawbuf_len], and [l], where 
-   *   [l = String.length ulb_rawbuf - ulb_rawbuf_len] is the free
-   *   space in the buffer. The function should fill new bytes into
-   *   this substring, and return the number of added bytes. The
-   *   return value 0 means EOF.
-   *)
-
-val close_unicode_lexbuf :
-      unicode_lexbuf -> unit
-  (** Sets [ulb_eof] of the [unicode_lexbuf]. The rest of the buffer
-   * is not modified
-   *)
-
-*)
-
 (**********************************************************************)
 
 (* Internal *)
@@ -1470,99 +1358,3 @@ val read_utf8_ref :
   * They are overriden by Netaccel (if linked)
   *)
 
-
-(* ======================================================================
- * History:
- * 
- * $Log: netconversion.mli,v $
- * Revision 2.13  2004/07/11 15:41:18  stolpmann
- * 	Added: IBM-1047 charset
- *
- * Revision 2.12  2004/07/10 23:43:06  stolpmann
- * 	ocamldoc
- *
- * Revision 2.11  2004/07/08 22:10:19  stolpmann
- * 	Adding accelerators for character set conversion.
- *
- * Revision 2.10  2004/07/07 22:41:54  stolpmann
- * 	Added Netulex, Netaux.ArrayAux.
- * 	Some improvements in Netconversion.
- *
- * Revision 2.9  2004/07/04 19:19:02  stolpmann
- * 	Updates ocamldoc
- *
- * Revision 2.8  2004/06/09 22:51:57  stolpmann
- * 	Enhanced cursors: Support for UTF-16 with BOMs, support for
- * incomplete multi-byte characters, blitting functions.
- * 	Added ocamldoc to Netconversion.
- * 	Updated test_recode: New tests for cursors.
- *
- * Revision 2.7  2003/06/03 18:58:23  stolpmann
- * 	Fine-tuning
- *
- * Revision 2.6  2003/04/21 22:01:36  stolpmann
- * 	Change: subst functions raise Cannot_represent by default (only
- * in new functions)
- * 	Obsolete: recode_string, recoding_pipe, makechar
- * 	New: same_encoding, byte_order_mark, uchar_string, from_unicode,
- * available_input_encodings, available_output_encodings, convert,
- * conversion_pipe
- * 	New: cursor implementation
- * 	New: unicode string functions
- *
- * Revision 2.5  2002/07/06 16:23:24  stolpmann
- * 	Fix: It is now checked and documented that the substitution
- * strings must not be too long. The limit is multibyte_limit, currently
- * 50 bytes.
- *
- * Revision 2.4  2002/07/03 01:15:57  stolpmann
- * 	New: `Enc_subset
- * 	New: is_single_byte
- * 	New: to_unicode
- *
- * Revision 2.3  2002/06/23 20:58:59  stolpmann
- * 	Added: Support for ISO-8858-16 character encoding
- *
- * Revision 2.2  2002/06/23 19:47:03  stolpmann
- * 	New class: recoding_pipe.
- * 	Fix: A possible problem in recode_string has been solved.
- * 	Improved representation of character mappings.
- *
- * Revision 2.1  2001/09/14 14:22:34  stolpmann
- * 	Initial revision (sourceforge)
- *
- *
- * ======================================================================
- * Revision 1.1  2000/08/13 00:02:57  gerd
- * 	Initial revision.
- *
- *
- * ======================================================================
- * OLD LOGS FROM THE PXP PACKAGE (FILE NAME pxp_encoding.mli):
- *
- * Revision 1.4  2000/07/04 22:05:58  gerd
- * 	Enhanced version of 'recode'. Labeled arguments.
- * New function 'recode_string'.
- *
- * Revision 1.3  2000/05/29 23:48:38  gerd
- * 	Changed module names:
- * 		Markup_aux          into Pxp_aux
- * 		Markup_codewriter   into Pxp_codewriter
- * 		Markup_document     into Pxp_document
- * 		Markup_dtd          into Pxp_dtd
- * 		Markup_entity       into Pxp_entity
- * 		Markup_lexer_types  into Pxp_lexer_types
- * 		Markup_reader       into Pxp_reader
- * 		Markup_types        into Pxp_types
- * 		Markup_yacc         into Pxp_yacc
- * See directory "compatibility" for (almost) compatible wrappers emulating
- * Markup_document, Markup_dtd, Markup_reader, Markup_types, and Markup_yacc.
- *
- * Revision 1.2  2000/05/29 21:14:57  gerd
- * 	Changed the type 'encoding' into a polymorphic variant.
- *
- * Revision 1.1  2000/05/20 20:30:50  gerd
- * 	Initial revision.
- *
- * 
- *)
