@@ -1,4 +1,4 @@
-(* $Id: netencoding.ml,v 2.17 2005/06/27 14:21:30 stolpmann Exp $
+(* $Id: netencoding.ml 1058 2006-12-17 19:52:30Z gerd $
  * ----------------------------------------------------------------------
  *
  *)
@@ -435,7 +435,7 @@ module Base64 = struct
       s ;;
 
     let decode_ignore_spaces s =
-      let (s_,_,_) = decode_prefix s 0 (String.length s) true true true false in
+      let (s,_,_) = decode_prefix s 0 (String.length s) true true true false in
       s ;;
 
     let decode_substring s ~pos ~len ~url_variant ~accept_spaces =
@@ -1585,94 +1585,3 @@ module Html = struct
            ()
 
 end
-	 
-	     
-
-(* ======================================================================
- * History:
- * 
- * $Log: netencoding.ml,v $
- * Revision 2.17  2005/06/27 14:21:30  stolpmann
- * Pcre: Newer versions of this library raise Not_found instead of
- * returning "" when get_substring does not have a matching string.
- *
- * Revision 2.16  2005/04/14 12:44:40  stolpmann
- * One can now select LF as line terminator for all message writing
- * functions. Netsendmail.sendmail defaults to LF for Unix compatiblity.
- *
- * Revision 2.15  2004/07/31 16:00:54  stolpmann
- * 	Bugfix QuotedPrintable: Space at end of string no longer causes
- * exception
- *
- * Revision 2.14  2004/07/18 16:36:24  stolpmann
- * 	New: Neturl.file_url_of_local_path, local_path_of_file_url.
- * 	URL updates according to RFC 2396.
- *
- * Revision 2.13  2004/07/11 15:51:18  stolpmann
- * 	Minor bugfix in QuotedPrintable.encoding_pipe: Spaces at the
- * end of the chunk but not at the end of the next are no longer
- * quoted.
- *
- * Revision 2.12  2004/07/04 21:02:37  stolpmann
- * 	Bug fix: QuotedPrintable takes care of adding soft line breaks.
- *
- * Revision 2.11  2004/05/30 21:53:08  stolpmann
- * 	Fix: Html.encode no longer encodes "0"
- *
- * Revision 2.10  2003/06/04 19:21:52  stolpmann
- * 	compile fixes
- *
- * Revision 2.9  2003/06/03 18:59:23  stolpmann
- * 	Follow-up change because of Netconversion updates.
- *
- * Revision 2.8  2002/07/06 16:24:06  stolpmann
- * 	Fix: `Enc_subset is now properly handled by Netencoding.Html.encode
- *
- * Revision 2.7  2002/07/03 01:16:38  stolpmann
- * 	New: Html.encode and Html.decode
- *
- * Revision 2.6  2002/02/02 23:54:06  stolpmann
- * 	Improvements for mbox mailboxes.
- *
- * Revision 2.5  2002/01/14 01:04:58  stolpmann
- * 	Netencoding.Url.mk/dest_url_encoded_parameters: These functions
- * now reside here and not in Cgi.
- *
- * Revision 2.4  2002/01/04 22:46:08  stolpmann
- * 	New: QuotedPrintable.encoding_pipe, and decoding_pipe.
- * 	The deprecated functions of [QuotedPrintable] and [Q] have been
- * moved into modules [Deprecated].
- *
- * Revision 2.3  2002/01/04 21:59:35  stolpmann
- * 	New: Base64.encoding_pipe, and Base64.decoding_pipe.
- * 	The deprecated Base64 functions have been moved into a
- * module [Deprecated].
- *
- * Revision 2.2  2001/09/23 20:39:42  pdoane
- * Migration to PCRE
- *
- * Revision 2.1  2001/09/14 14:22:34  stolpmann
- * 	Initial revision (sourceforge)
- *
- *
- * ======================================================================
- * Revision 1.6  2001/08/30 19:45:43  gerd
- * 	Module Url: added the option ~plus
- *
- * Revision 1.5  2000/06/25 22:34:43  gerd
- * 	Added labels to arguments.
- *
- * Revision 1.4  2000/06/25 21:15:48  gerd
- * 	Checked thread-safety.
- *
- * Revision 1.3  2000/03/03 17:03:16  gerd
- * 	Q encoding: CR and LF are quoted.
- *
- * Revision 1.2  2000/03/03 01:08:29  gerd
- * 	Added Netencoding.Html functions.
- *
- * Revision 1.1  2000/03/02 01:14:48  gerd
- * 	Initial revision.
- *
- * 
- *)
