@@ -1,4 +1,4 @@
-(* $Id: nethtml.ml,v 2.9 2005/01/22 10:58:26 stolpmann Exp $
+(* $Id: nethtml.ml 1062 2006-12-17 20:17:36Z gerd $
  * ----------------------------------------------------------------------
  *
  *)
@@ -399,9 +399,15 @@ let parse_document ?(dtd = html40_dtd)
   in
 
   let parse_atts() =
-    let rec next_no_space() =
-      match scan_element buf with
-	  Space _ -> next_no_space()
+    let rec next_no_space p_string =
+      (* p_string: whether string literals in quotation marks are allowed *)
+      let tok =
+	if p_string then
+	  scan_element_after_Is buf
+	else
+	  scan_element buf in
+      match tok with
+	  Space _ -> next_no_space p_string
 	| t -> t
     in
 
@@ -409,15 +415,15 @@ let parse_document ?(dtd = html40_dtd)
       match next with
 	  Relement -> []
       	| Name n ->
-	    begin match next_no_space() with
+	    begin match next_no_space false with
 	      	Is ->
-		  begin match next_no_space() with
+		  begin match next_no_space true with
 		      Name v ->
 		      	(String.lowercase n, v) ::
-			parse_atts_lookahead (next_no_space())
+			parse_atts_lookahead (next_no_space false)
 		    | Literal v ->
 		      	(String.lowercase n,v) ::
-			parse_atts_lookahead (next_no_space())
+			parse_atts_lookahead (next_no_space false)
 		    | Eof ->
 		      	raise End_of_scan
 		    | Relement ->
@@ -425,7 +431,7 @@ let parse_document ?(dtd = html40_dtd)
 		      	[]
 		    | _ ->
 		      	(* Illegal *)
-		      	parse_atts_lookahead (next_no_space())
+		      	parse_atts_lookahead (next_no_space false)
 		  end
 	      | Eof ->
 		  raise End_of_scan
@@ -441,9 +447,9 @@ let parse_document ?(dtd = html40_dtd)
 	    raise End_of_scan
       	| _ ->
 	    (* Illegal *)
-	    parse_atts_lookahead (next_no_space())
+	    parse_atts_lookahead (next_no_space false)
     in
-    parse_atts_lookahead (next_no_space())
+    parse_atts_lookahead (next_no_space false)
   in
 
   let rec parse_special name =
@@ -587,8 +593,8 @@ let parse_document ?(dtd = html40_dtd)
 	  parse_next()
   in
   try
-    parse_next();
-    List.rev !current_subs
+    parse_next();  (* never returns. Will get a warning X *)
+    assert false
   with
       End_of_scan ->
 	(* Close all remaining elements: *)
@@ -639,9 +645,9 @@ let encode ?(enc = `Enc_iso88591) ?(prefer_name = true) dl =
   map_list enc_string dl
 ;;
 
-let decode ?(enc = `Enc_iso88591) ?subst dl = 
+let decode ?(enc = `Enc_iso88591) ?subst ?entity_base ?lookup dl = 
   let dec_string =
-    Netencoding.Html.decode ~in_enc:enc ~out_enc:enc ?subst () in
+    Netencoding.Html.decode ~in_enc:enc ~out_enc:enc ?subst ?entity_base ?lookup () in
   map_list dec_string dl
 ;;
 
@@ -708,97 +714,3 @@ let write_ ~dtd write_os doc =
 
 let write ?(dtd = html40_dtd) ch doc =
   write_ ~dtd (ch # output_string) doc
-
-
-(* ======================================================================
- * History:
- * 
- * $Log: nethtml.ml,v $
- * Revision 2.9  2005/01/22 10:58:26  stolpmann
- * Error: FORM, BLOCKQUOTE: Content is "flow" in the transitional DTD, not
- * "block" as in the strict DTD.
- *
- * Revision 2.8  2004/07/08 23:04:25  stolpmann
- * 	ocamldoc
- *
- * Revision 2.7  2004/06/23 21:47:52  stolpmann
- * 	Handling of essential blocks was wrong when the block was
- * the direct parent of the element to add. The block was implicitly
- * closed in this case although this is not allowed (e.g.
- * <ul><li>x</li><ol><li>y</li></ol></ul>: When <ol> is found, the
- * ul element must not be closed).
- * 	This is now fixed.
- *
- * Revision 2.6  2003/03/02 13:09:28  stolpmann
- * 	Fixed dl model
- *
- * Revision 2.5  2002/07/06 16:26:25  stolpmann
- * 	It is now document that the parser can cope with any ASCII-
- * compatible character encoding. Furthermore, the [encode] and [decode]
- * functions have been generalized, and they work now for every
- * ASCII-compatible character encoding.
- *
- * Revision 2.4  2001/12/22 09:18:02  pdoane
- * 	Call Netchannels.lexbuf_of_in_obj_channel instead of
- * Lexing.from_function
- *
- * Revision 2.3  2001/12/16 20:25:02  pdoane
- * 	Updated to use Netchannels
- *
- * Revision 2.2  2001/12/07 00:36:26  stolpmann
- * 	Added forgotten element <tbody>.
- *
- * Revision 2.1  2001/09/14 14:22:34  stolpmann
- * 	Initial revision (sourceforge)
- *
- *
- * ======================================================================
- * Revision 1.9  2001/08/31 22:11:56  gerd
- * 	Added essential blocks.
- *
- * Revision 1.8  2001/07/15 15:00:55  gerd
- * 	Relaxed the DTD.
- *
- * Revision 1.7  2001/07/15 14:20:54  gerd
- * 	Bugfix: Sometimes too many elements were closed when an
- * end tag was found. This is fixed now.
- * 	New relaxed_html40_dtd.
- * 	New constraint `Sub_exclusions. html40_dtd uses this
- * constraint already.
- * 	Attribute values without quotes are no longer converted
- * to uppercase.
- *
- * Revision 1.6  2001/06/10 23:56:50  gerd
- * 	Fix: 'write' no longer writes end tags of empty elements.
- *
- * Revision 1.5  2001/06/08 22:21:03  gerd
- * 	Fix: if 'write' is applied to bad documents a Failure will
- * be raised instead of Not_found.
- *
- * Revision 1.4  2001/06/08 22:19:55  gerd
- * 	Added functions encode, decode, write for convenience.
- *
- * Revision 1.3  2001/06/08 16:25:27  gerd
- * 	Bugfix: </SCRIPT> is now recognized (thanks to David Fox)
- * 	The parser may now return comments, declarations, and processing
- * instructions if requested to do so
- * 	The parser accepts xhtml to some extent
- * 	Now exported: parse_document.
- *
- * Revision 1.2  2001/04/07 23:38:26  gerd
- * 	Added a simplified representation of the DTD. This improves
- * the quality of the parser drastically. For example,
- * "<p>abc<p>def" is no longer parsed as "<p>abc<p>def</p></p>",
- * but as "<p>abc</p><p>def</p>". However, the representation is not
- * perfect yet. What's definitly missing are the exclusion lists
- * of the DTD. Because of this missing feature, "<a>abc<a>def" is
- * still parsed as "<a>abc<a>def</a></a>" although the DTD states
- * that anchors cannot contain anchors ( - but it also states that
- * end tags of anchors cannot be omitted, so this feature is not
- * priority 1).
- *
- * Revision 1.1  2000/03/03 01:07:25  gerd
- * 	Initial revision.
- *
- * 
- *)
