@@ -1,4 +1,4 @@
-(* $Id: nethtml.mli,v 2.4 2004/07/08 23:04:25 stolpmann Exp $
+(* $Id: nethtml.mli 1013 2006-10-02 13:20:18Z gerd $
  * ----------------------------------------------------------------------
  *
  *)
@@ -240,6 +240,8 @@ val parse : ?dtd:simplified_dtd ->            (* default: html40_dtd *)
 val decode : 
       ?enc:Netconversion.encoding ->           (* default: `Enc_iso88591 *)
       ?subst:(int -> string) ->                (* default: failure *)
+      ?entity_base:[ `Html | `Xml | `Empty ] -> 
+      ?lookup:(string -> string) ->
       document list -> document list
   (** Converts entities [&name;] and [&#num;] into the corresponding 
    * characters. The argument [enc] must indicate the character set of
@@ -249,6 +251,10 @@ val decode :
    * substituted string). By default, the function fails if such a 
    * character is found.
    *
+   * The arg [entity_base] selects which entities can be converted
+   * (see {!Netencoding.Html.decode}). The function [lookup] is called
+   * for all unknown [&name;] entities. By default, this function fails.
+   *
    * Note: Declarations, processing instructions, and comments are not
    * decoded.
    *)
@@ -300,62 +306,3 @@ val write : ?dtd:simplified_dtd ->            (* default: html40_dtd *)
    *
    * @param dtd The assumed simplified DTD, by default [html40_dtd]
    *)
-
-(* ======================================================================
- * History:
- * 
- * $Log: nethtml.mli,v $
- * Revision 2.4  2004/07/08 23:04:25  stolpmann
- * 	ocamldoc
- *
- * Revision 2.3  2002/07/06 16:26:25  stolpmann
- * 	It is now document that the parser can cope with any ASCII-
- * compatible character encoding. Furthermore, the [encode] and [decode]
- * functions have been generalized, and they work now for every
- * ASCII-compatible character encoding.
- *
- * Revision 2.2  2001/12/16 20:25:02  pdoane
- * 	Updated to use Netchannels
- *
- * Revision 2.1  2001/09/14 14:22:34  stolpmann
- * 	Initial revision (sourceforge)
- *
- *
- * ======================================================================
- * Revision 1.7  2001/08/31 22:11:56  gerd
- * 	Added essential blocks.
- *
- * Revision 1.6  2001/07/15 14:18:59  gerd
- * 	New relaxed_html40_dtd.
- * 	New constraint `Sub_exclusions.
- *
- * Revision 1.5  2001/06/10 23:56:50  gerd
- * 	Fix: 'write' no longer writes end tags of empty elements.
- *
- * Revision 1.4  2001/06/08 22:19:55  gerd
- * 	Added functions encode, decode, write for convenience.
- *
- * Revision 1.3  2001/06/08 16:25:27  gerd
- * 	Bugfix: </SCRIPT> is now recognized (thanks to David Fox)
- * 	The parser may now return comments, declarations, and processing
- * instructions if requested to do so
- * 	The parser accepts xhtml to some extent
- * 	Now exported: parse_document.
- *
- * Revision 1.2  2001/04/07 23:38:26  gerd
- * 	Added a simplified representation of the DTD. This improves
- * the quality of the parser drastically. For example,
- * "<p>abc<p>def" is no longer parsed as "<p>abc<p>def</p></p>",
- * but as "<p>abc</p><p>def</p>". However, the representation is not
- * perfect yet. What's definitly missing are the exclusion lists
- * of the DTD. Because of this missing feature, "<a>abc<a>def" is
- * still parsed as "<a>abc<a>def</a></a>" although the DTD states
- * that anchors cannot contain anchors ( - but it also states that
- * end tags of anchors cannot be omitted, so this feature is not
- * priority 1).
- *
- * Revision 1.1  2000/03/03 01:07:25  gerd
- * 	Initial revision.
- *
- * 
- *)
