@@ -1,4 +1,4 @@
-(* $Id: nethttp.ml,v 2.1 2005/07/25 22:36:41 stolpmann Exp $ 
+(* $Id: nethttp.ml 1062 2006-12-17 20:17:36Z gerd $ 
  * ----------------------------------------------------------------------
  * Nethttp: Basic definitions for the HTTP protocol
  *)
@@ -266,7 +266,9 @@ let strong_validator_match e1 e2 =
 exception Bad_header_field of string
 
 class type http_header = Netmime.mime_header
+class type http_header_ro = Netmime.mime_header_ro
 class type http_trailer = Netmime.mime_header
+class type http_trailer_ro = Netmime.mime_header_ro
 
 
 type cookie =
@@ -299,7 +301,7 @@ let status_of_cgi_header hdr =
 	Not_found ->
 	  (* Maybe there is a [Location] header: *)
 	  ( try
-	      let location = hdr # field "Location" in
+	      let _location = hdr # field "Location" in
 	      (302, "Found")
 	    with
 		Not_found ->
