@@ -1,4 +1,4 @@
-(* $Id: rpc_time.ml 459 2006-04-30 19:49:19Z gerd $
+(* $Id: rpc_time.ml 1137 2007-07-31 15:48:47Z gerd $
  * ----------------------------------------------------------------------
  *
  *)
@@ -10,7 +10,8 @@ let remote_time ?(timeout = 5) peer =
   let add_action f = cleanup := f :: !cleanup in
   let do_cleanup() = List.iter (fun f -> f()) !cleanup; cleanup := [] in
   try
-    let s = Unix.socket Unix.PF_INET Unix.SOCK_STREAM 0 in
+    let dom = Netsys.domain_of_inet_addr peer in
+    let s = Unix.socket dom Unix.SOCK_STREAM 0 in
     add_action (fun () -> Unix.close s);
     Unix.set_nonblock s;               (* so that Unix.connect does not block *)
     ( try
