@@ -1,4 +1,4 @@
-(* $Id: rpc_server.ml 986 2006-08-28 14:12:35Z gerd $
+(* $Id: rpc_server.ml 1121 2007-05-06 18:20:37Z gerd $
  * ----------------------------------------------------------------------
  *
  *)
@@ -1038,9 +1038,11 @@ let create2_socket_server ?(config = default_socket_config)
   in
 
   let bind_to_internet addr port =
+    let dom = Netsys.domain_of_inet_addr addr in
+
     let s =
       Unix.socket
-	Unix.PF_INET
+	dom
 	(if prot = Tcp then Unix.SOCK_STREAM else Unix.SOCK_DGRAM)
 	0
     in
